@@ -259,8 +259,10 @@ svyrecvar<-function(x, clusters,  stratas, fpcs, postStrata=NULL,
       } else {
         ## ordinary post-stratification
         psw<-attr(psvar, "weights")
+        oldw<-attr(psvar, "oldweights")
+        if (is.null(oldw)) oldw<-rep(1,length(psw))
         psvar<-as.factor(psvar)
-        psmeans<-rowsum(x/psw,psvar,reorder=TRUE)/as.vector(table(factor(psvar)))
+        psmeans<-rowsum(x*oldw/psw,psvar,reorder=TRUE)/as.vector(by(oldw,psvar,sum))
         x<- x-psmeans[match(psvar,sort(unique(psvar))),]*psw
       }
     }
